/*-=-=-=-=-=-=-=-=-=-=-=- RCCL/RCI Notice of Copyright -=-=-=-=-=-=-=-=-=-=-*
 *									    *
 *	Copyright (C) 1987, 1991 by Mike Parker.			    *
 *									    *
 *	Information on copyright permissions, as well as a complete	    *
 *	disclaimer of warranty, is given in the file COPYRIGHT.		    *
 *									    *
 *-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=*/

#ifndef _CTREE_H_
#define _CTREE_H_

/* Definitions useful required for the Ctree matcher. 
  
   NOTE: this definition file assumes the user of 'key_buf' as the name
   for the buffer in which matches are returned.

*/

#include <stdio.h>

char *tree_match_parse();
char *tree_match_err_at();
int *tree_match_flags();
FILE *tree_match_input_stream();

#define	COMMAND(s)	(strcmp (key_buf, s) == 0)
#define	COMMANDS(s)	(strncmp (key_buf, s, strlen(s)) == 0)

#define CTREE_F_DEBUG 0x00000001

#endif
